__author__ = "Alex DeLorenzo"
from setuptools import setup
from pathlib import Path


NAME = "onhold"
VERSION = "0.6.4"
LICENSE = "AGPL-3.0"

DESC = "🔊 Play music while and after jobs complete"

REQUIREMENTS = \
  Path('requirements.txt') \
    .read_text() \
    .split('\n')

README = Path('README.md').read_text()

ENTRY_POINTS = {
  "console_scripts":
    [f"{NAME} = {NAME}.during:cmd",
      f"ding = {NAME}.after:cmd"]
}

setup(
  name=NAME,
  version=VERSION,
  description=DESC,
  long_description=README,
  long_description_content_type="text/markdown",
  url="https://alexdelorenzo.dev",
  author=__author__,
  license=LICENSE,
  packages=[NAME],
  zip_safe=True,
  install_requires=REQUIREMENTS,
  entry_points=ENTRY_POINTS,
  python_requires='>=3.6',
  include_package_data=True,
)



from contextlib import contextmanager
from typing import Optional, ContextManager
from sys import stdin, stdout, stderr, exit
from pathlib import Path
from os import environ

from play_sounds import DEFAULT_SONG


RC_OK = 0
RC_ENV_VAR = 1
ENV_VAR = 'ONHOLD'

KB = 2 ** 10
CHUNK = 64 * KB


def is_pipeline() -> bool:
  return not stdin.isatty()


# python 3.8+ compatible
# def dumb_pipe():
#   while data := stdin.buffer.read(CHUNK):
#     stdout.buffer.write(data)


# python 3.6 compatible
def dumb_pipe():
  while True:
    data = stdin.buffer.read(CHUNK)

    if not data:
      break

    stdout.buffer.write(data)


@contextmanager
def using_path(
  sound_path: Optional[str],
  warn: bool,
  default: Optional[Path] = DEFAULT_SONG,
  env_var: str = ENV_VAR,
) -> ContextManager[Optional[Path]]:
  path = default

  if sound_path:
    path = Path(str(sound_path))

#   elif var := environ.get(env_var):
#     path = Path(var)

  elif env_var in environ:
    path = Path(environ[env_var])

  elif warn:
    stderr.write(f"Please set ${env_var} or use the -s flag.\n")

  yield path

  if path:
    exit(RC_OK)

  else:
    exit(RC_ENV_VAR)



from typing import Optional
from pathlib import Path

from play_sounds import play_while_running, bell_after
import click

from .base import dumb_pipe, using_path


def run(file: Optional[Path] = None):
  if not file:
    dumb_pipe()
    return

  with play_while_running(file):
    dumb_pipe()


@click.command(
  help=(
    "Play the specified sound file while data is passed in "
    "through standard input and passed through standard output."
  )
)
@click.option('-s', '--sound_path', required=False,
  type=click.Path(exists=True), help="Path to sound to play.")
@click.option('-b', '--bell', required=False,
  default=False, show_default=True, is_flag=True,
  type=click.BOOL, help="Ring the terminal bell, as well.")
@click.option('-w', '--warn', required=False,
  is_flag=True, default=False, help="Show warnings.")
def cmd(sound_path: Optional[str], bell: bool, warn: bool):
  with bell_after(bell), \
       using_path(sound_path, warn) as path:
    run(path)


if __name__ == "__main__":
  cmd()
